@@ -1,7 +1,7 @@
 import unittest
 
 from pyais import decode_msg
-from pyais.exceptions import InvalidNMEAMessageException
+from pyais.exceptions import InvalidNMEAMessageException, MissingMultipartMessageException, TooManyMessagesException
 
 
 class TestDecode(unittest.TestCase):
@@ -64,9 +64,36 @@ class TestDecode(unittest.TestCase):
         self.assertEqual(decoded["shipname"], "NORDIC HAMBURG")
         self.assertEqual(decoded["destination"], "CTT-LAYBY")
 
-        decoded = decode_msg(
-            b'!AIVDM,2,1,1,A,538CQ>02A;h?D9QC800pu8@T>0P4l9E8L0000017Ah:;;5r50Ahm5;C0,0*07',
-            b'!AIVDM,2,2,1,A,F@V@00000000000,2*35',
-            b'!AIVDM,2,1,9,A,538CQ>02A;h?D9QC800pu8@T>0P4l9E8L0000017Ah:;;5r50Ahm5;C0,0*0F',
-            b'!AIVDM,2,2,9,A,F@V@00000000000,2*3D',
+    def test_too_many_messages(self):
+        with self.assertRaises(TooManyMessagesException) as err:
+            decode_msg(
+                b'!AIVDM,2,1,1,A,538CQ>02A;h?D9QC800pu8@T>0P4l9E8L0000017Ah:;;5r50Ahm5;C0,0*07',
+                b'!AIVDM,2,2,1,A,F@V@00000000000,2*35',
+                b'!AIVDM,2,1,9,A,538CQ>02A;h?D9QC800pu8@T>0P4l9E8L0000017Ah:;;5r50Ahm5;C0,0*0F',
+                b'!AIVDM,2,2,9,A,F@V@00000000000,2*3D',
+            )
+        self.assertEqual(str(err.exception), "Got 4 messages, but fragment count is 2")
+
+    def test_multipart_error_message(self):
+        """Refer to issue #37"""
+        msg_1 = "!AIVDM,2,1,0,A,539p4OT00000@7W3K@08ThiLE8@E:0000000001S0h9135Pl?0R0C@UDQp00,0*68"
+        msg_2 = "!AIVDM,2,2,0,A,00000000000,2*24"
+
+        with self.assertRaises(MissingMultipartMessageException) as err:
+            decode_msg(msg_1)
+        self.assertEqual(str(err.exception), "Missing fragment numbers: [2]")
+
+        with self.assertRaises(MissingMultipartMessageException) as err:
+            decode_msg(msg_2)
+        self.assertEqual(str(err.exception), "Missing fragment numbers: [1]")
+
+        with self.assertRaises(MissingMultipartMessageException) as err:
+            decode_msg(
+                "!AIVDM,3,2,0,A,539p4OT00000@7W3K@08ThiLE8@E:0000000001S0h9135Pl?0R0C@UDQp00,0*68",
+            )
+        self.assertEqual(str(err.exception), "Missing fragment numbers: [1, 3]")
+
+        decode_msg(
+            msg_1,
+            msg_2
         )
