@@ -160,14 +160,14 @@ class TestOutOfOrder(unittest.TestCase):
         iter_steam = iter(stream)
 
         # assure that messages are deleted after they are yielded
-        assert next(iter_steam).seq_id == b'1'
+        assert next(iter_steam).message_id == 1
         assert len(stream._queue) == 2
-        assert next(iter_steam).seq_id == b'7'
+        assert next(iter_steam).message_id == 7
         assert len(stream._queue) == 1
 
     def test_three(self):
         messages = [
-            b"AIVDM,3,1,5,A,36KVnDh02wawaHPDA8T8h6tT8000t=AV=maD7?>BWiKIE@TR<2QfvaAF1ST4H31B,0*35",
+            b"!AIVDM,3,1,5,A,36KVnDh02wawaHPDA8T8h6tT8000t=AV=maD7?>BWiKIE@TR<2QfvaAF1ST4H31B,0*35",
             b"!AIVDM,3,2,5,A,8IBP:UFW<M0FVWS0DPK19@nh4UdS:OufWUIfPF5l1U9LILBn@9@F:41Q@U1EEOE3,0*1D",
             b"!AIVDM,3,3,5,A,j,0*79"
         ]
